@@ -57,11 +57,12 @@ func runList(ctx context.Context) (err error) {
 			app.Name,
 			app.Organization.Slug,
 			app.Status,
+			app.PlatformVersion,
 			latestDeploy,
 		})
 	}
 
-	_ = render.Table(out, "", rows, "Name", "Owner", "Status", "Latest Deploy")
+	_ = render.Table(out, "", rows, "Name", "Owner", "Status", "Platform", "Latest Deploy")
 
 	return
 }
