@@ -84,11 +84,23 @@ func runListDbs(ctx context.Context) error {
 	}
 	ctx = agent.DialerWithContext(ctx, dialer)
 
+	var leaderIp string
 	switch app.PlatformVersion {
 	case "nomad":
 		if err := hasRequiredVersionOnNomad(app, MinPostgresHaVersion, MinPostgresHaVersion); err != nil {
 			return err
 		}
+		pgInstances, err := agentclient.Instances(ctx, app.Organization.Slug, app.Name)
+		if err != nil {
+			return fmt.Errorf("failed to lookup 6pn ip for %s app: %v", app.Name, err)
+		}
+		if len(pgInstances.Addresses) == 0 {
+			return fmt.Errorf("no 6pn ips found for %s app", app.Name)
+		}
+		leaderIp, err = leaderIpFromNomadInstances(ctx, pgInstances.Addresses)
+		if err != nil {
+			return err
+		}
 	case "machines":
 		flapsClient, err := flaps.New(ctx, app)
 		if err != nil {
@@ -102,11 +114,16 @@ func runListDbs(ctx context.Context) error {
 		if err := hasRequiredVersionOnMachines(members, MinPostgresHaVersion, MinPostgresHaVersion); err != nil {
 			return err
 		}
+		if len(members) == 0 {
+			return fmt.Errorf("no 6pn ips founds for %s app", app.Name)
+		}
+		leader, _ := machinesNodeRoles(ctx, members)
+		leaderIp = leader.PrivateIP
 	default:
 		return fmt.Errorf("unsupported platform %s", app.PlatformVersion)
 	}
 
-	pgclient := flypg.New(appName, dialer)
+	pgclient := flypg.NewFromInstance(leaderIp, dialer)
 
 	databases, err := pgclient.ListDatabases(ctx)
 	if err != nil {
